from django import forms
from django.contrib.auth.models import User, Group
from .models import Account, User, Club, Screen, Cinema, Showing, Film, ClubRepresentative, EndOfMonthStatement
from django.contrib.auth.forms import AuthenticationForm, UserCreationForm

class AccountForm(forms.ModelForm):
    club = forms.ModelChoiceField(queryset=Club.objects.all())
    class Meta:
        model = Account
        fields = ['payment_card_number', 'payment_card_expiry_date', 'discount_rate']


class UserRegistrationForm(UserCreationForm):
    
    class Meta:
        model = User
        fields = ("email", "username", "first_name", "last_name", "date_of_birth", "password1", "password2")    


class ClubForm(forms.ModelForm):
    class Meta:
        model = Club
        fields = ['name', 'address_details', 'contact_details']


class ClubRepresentativeForm(forms.ModelForm):
    class Meta:
        model = ClubRepresentative
        fields = ['email', 'first_name', 'last_name', 'password']
        
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['password'].widget.attrs.update({'autocomplete': 'new-password'})

class ElevateUserForm(forms.ModelForm):
    user = forms.ModelChoiceField(queryset=User.objects.all().filter(is_rep=False))
    group = forms.ChoiceField(choices=[
        ('account_manager', 'Account Manager'),
        ('cinema_manager', 'Cinema Manager')
    ])

    class Meta:
        model = User
        fields = ['user', 'group']

class ScreenForm(forms.ModelForm):
    cinema = forms.ModelChoiceField(queryset=Cinema.objects.all())

    class Meta:
        model = Screen
        fields = ['cinema', 'screen_number', 'seating_capacity']

class CinemaForm(forms.ModelForm):
    class Meta:
        model = Cinema
        fields = ['name', 'location']

class ShowingForm(forms.ModelForm):
    screen = forms.ModelChoiceField(queryset=Screen.objects.all())
    film = forms.ModelChoiceField(queryset=Film.objects.all())
    class Meta:
        model = Showing
        fields = ['screen', 'film', 'start_time']

class FilmForm(forms.ModelForm):
    class Meta:
        model = Film
        fields = ['title', 'length', 'rating']
        
        
class EndOfMonthStatementForm(forms.ModelForm):
    class Meta:
        model = EndOfMonthStatement
        fields = ['date', 'total_spent', 'total_paid', 'outstanding']